# falco-python
Fast Linearized Coronagraph Optimizer (FALCO) in Python 3

**********************************************
### DOCUMENTATION UNDER DEVELOPMENT

* The only non-standard library you need is PROPER, available only via download here: https://sourceforge.net/projects/proper-library/
* To get started, add PROPER and falco-python to your PYTHONPATH. Then try running some scripts in the falco-python/examples/ folder starting with EXAMPLE_main* or demo_*.
* The Lyot coronagraph, vortex coronagraph, and shaped pupil Lyot coronagraph modes are now operational and have been validated against the MATLAB versions.
**********************************************
